@@ -65,8 +65,9 @@ def load_active_content(path=''):
     PORT = server_config.pop("PORT")
     NAMESPACE = server_config.pop("NAMESPACE")
     GROUP = server_config.pop("GROUP")
+    set_config_dict = {}
     if server_config:
-        for k in server_config:
-            server_config[k.lower()] = server_config.pop(k)
-    new_instance = Instance(SERVER_NAME, IP, PORT, GROUP, NAMESPACE, **server_config)
+        for k, v in server_config.items():
+            set_config_dict[k.lower()] = v
+    new_instance = Instance(SERVER_NAME, IP, PORT, GROUP, NAMESPACE, **set_config_dict)
     return new_instance
